@@ -2,8 +2,10 @@
 # SPDX-License-Identifier: Apache-2.0
 import logging
 import os
+import time
 import uuid
 from enum import Enum
+from typing import Optional
 
 from airflow.exceptions import AirflowException
 from airflow.providers.http.hooks.http import HttpHook
@@ -44,7 +46,7 @@ class VDKHook(HttpHook):
         conn_id: str,
         job_name: str,
         team_name: str,
-        timeout: int = 1,  # TODO: Set reasonable default
+        timeout: int = 5,  # TODO: Set reasonable default
     ):
         super().__init__(http_conn_id=conn_id)
         self.job_name = job_name
@@ -68,7 +70,7 @@ class VDKHook(HttpHook):
 
         self.__execution_api = self._get_execution_api()
 
-    def start_job_execution(self, **request_kwargs) -> None:
+    def start_job_execution(self, **request_kwargs) -> str:
         """
         Triggers a manual Datajob execution.
 
@@ -87,6 +89,9 @@ class VDKHook(HttpHook):
         )
         log.debug(f"Received headers: {headers}")
 
+        job_execution_id = os.path.basename(headers["Location"])
+        return job_execution_id
+
     def cancel_job_execution(self, execution_id: str) -> None:
         """
         Cancels a Datajob execution.
@@ -122,6 +127,49 @@ class VDKHook(HttpHook):
             team_name=self.team_name, job_name=self.job_name, execution_id=execution_id
         )
 
+    def wait_for_job(
+        self, execution_id, wait_seconds: float = 3, timeout: Optional[float] = 60 * 60
+    ):
+        start = time.monotonic()
+        while True:
+            if timeout and start + timeout < time.monotonic():
+                raise VDKJobExecutionException(
+                    f"Timeout: Data Job execution {execution_id} is not complete after {timeout}s"
+                )
+            time.sleep(wait_seconds)
+
+            try:
+                job_execution = self.get_job_execution_status(execution_id)
+                job_status = job_execution.status
+            except Exception as err:
+                self.log.info("VDK Control Service returned error: %s", err)
+                continue
+
+            if job_status == JobStatus.SUCCEEDED:
+                log.info(f"Job status: {job_execution}")
+                log.info(f"Job logs: {self.get_job_execution_log(execution_id)}")
+
+                break
+            elif job_status == JobStatus.SUBMITTED or job_status == JobStatus.RUNNING:
+                continue
+            elif job_status == JobStatus.CANCELLED or job_status == JobStatus.SKIPPED:
+                raise VDKJobExecutionException(
+                    f"Job execution {execution_id} has been {job_status}."
+                )
+            elif (
+                job_status == JobStatus.USER_ERROR
+                or job_status == JobStatus.PLATFORM_ERROR
+            ):
+                log.info(f"Job logs: {self.get_job_execution_log(execution_id)}")
+                raise VDKJobExecutionException(
+                    f"Job execution {execution_id} has failed due to a {job_status.replace('_', ' ')}. "
+                    f"Check the job execution logs above for more information."
+                )
+            else:
+                raise VDKJobExecutionException(
+                    f"Encountered unexpected status `{job_status}` for job execution `{execution_id}`"
+                )
+
     def _get_rest_api_url_from_connection(self):
         conn = self.get_connection(self.http_conn_id)
 
